# Generated by Django 4.0.6 on 2022-10-15 04:35

import ckeditor.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('jeral', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='GrupuBambu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255, verbose_name='Naran Grupu')),
                ('naran_kordenador', models.CharField(blank=True, max_length=255, null=True, verbose_name='Naran Kordenador')),
                ('kordinate_centru', models.CharField(max_length=255)),
                ('kordinate_area', models.TextField(blank=True, null=True)),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('imagen', models.ImageField(blank=True, default='grupubambu/default.png', null=True, upload_to='grupubambu/')),
                ('kontaktu', models.CharField(blank=True, max_length=255, null=True)),
                ('hashed', models.TextField()),
                ('suku', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.suku', verbose_name='Hili Suku')),
                ('user_created', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Hili User')),
            ],
            options={
                'verbose_name_plural': 'Grupu Bambu',
            },
        ),
        migrations.CreateModel(
            name='ImportasaunBambu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data_importasaun', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('kuantidade', models.CharField(blank=True, max_length=200, null=True, verbose_name='Quantidade')),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255, verbose_name='Deskrisaun')),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('hashed', models.TextField(blank=True, null=True)),
                ('grupubambu', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='mapa.grupubambu', verbose_name='Hili Grupu Bambu')),
                ('user_created', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Hili User')),
            ],
            options={
                'verbose_name_plural': 'Grupu Bambu',
            },
        ),
        migrations.CreateModel(
            name='GrupuViveirus',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255, verbose_name='Naran Grupu')),
                ('naran_kordenador', models.CharField(blank=True, max_length=255, null=True, verbose_name='Naran Kordenador')),
                ('kordinate_centru', models.CharField(max_length=255)),
                ('kordinate_area', models.TextField(blank=True, null=True)),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('imagen', models.ImageField(blank=True, default='grupuviveirus/default.png', null=True, upload_to='grupuviveirus/')),
                ('kontaktu', models.CharField(blank=True, max_length=255, null=True)),
                ('hashed', models.TextField()),
                ('suku', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.suku', verbose_name='Hili Suku')),
                ('user_created', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User Kria')),
            ],
            options={
                'verbose_name_plural': 'Grupu Viveirus',
            },
        ),
        migrations.CreateModel(
            name='AreaBambu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255)),
                ('naran_kordenador', models.CharField(blank=True, max_length=255, null=True, verbose_name='Naran Kordenador')),
                ('kordinate_centru', models.CharField(max_length=255)),
                ('hectar', models.CharField(blank=True, max_length=255, null=True, verbose_name='Hectar')),
                ('kordinate_area', models.TextField()),
                ('imagen', models.ImageField(blank=True, default='areabambu/default.png', null=True, upload_to='areabambu/')),
                ('kontaktu', models.CharField(blank=True, max_length=255, null=True)),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('kor', models.CharField(blank=True, max_length=255, null=True)),
                ('hashed', models.TextField()),
                ('suku', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.suku', verbose_name='Hili Suku')),
                ('user_created', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User Kria')),
            ],
            options={
                'verbose_name_plural': 'Area Bambu',
            },
        ),
    ]
