{% extends 'main/dashboard.html' %}


{% load static %}
{% block content %}
         

{% load crispy_forms_tags %} 








<div class="container-xxl flex-grow-1 container-p-y">
  <h4 class="fw-bold py-3 mb-4">

    <span class="text-muted fw-light">Mapamentu /</span>  <a href="{% url 'mapa:grupubambu' %}">Dados Grupu Pre - Fabrica </a> /  <a href="{% url 'mapa:rejistuimportasaunbambu' idgrupubambu %}">{{naran_grupu}} </a>  <span class="text-muted fw-light">  / Rejistu Inportasaun</span> 
  
  
  
  </h4>


  
  <div class="row">






  <div class="col-lg-12 mb-4" style="margin-bottom: 0.2rem !important;">
    <div class="col-xxl">
      <div class="card mb-4">
        <div class="card-header d-flex align-items-center justify-content-between">
          <h5 class="mb-0">Prenxe Formulariu</h5>
     
        </div>
        <div class="card-body"> 
          {% crispy forms %}


        </div>
      </div>
    </div>


</div>


  
  
</div>
                                    
              

                    
{% endblock content %}


               
              

