from django.contrib import admin
from dokumentu.models import *
# Register your models here.


admin.site.register(Lingua)
admin.site.register(Rejiaun)
admin.site.register(Nasaun)
admin.site.register(Lokalizasaun)
admin.site.register(KategoriaDoc)
admin.site.register(Dokumentu)
admin.site.register(FileUpload)
admin.site.register(Komentariu)